@@ -103,6 +103,7 @@ find_statistic <- function(x, ...) {
     "pb1", "pb2", "polr", "phylolm",
     "rlm", "rms", "rlmerMod", "rq", "rqs", "rqss",
     "selection", "speedlm", "spml", "summary.lm", "svyglm", "svyolr", "systemfit",
+    "svy2lme",
     "truncreg",
     "varest",
     "wbm", "wblm",
@@ -121,7 +122,7 @@ find_statistic <- function(x, ...) {
     "ergm",
     "feglm", "flexsurvreg",
     "gee", "ggcomparisons", "glimML", "glmm", "glmmadmb", "glmmFit", "glmmLasso",
-    "glmmTMB", "glmx", "gmnl",
+    "glmmTMB", "glmx", "gmnl", "glmgee",
     "hurdle",
     "lavaan", "loggammacenslmrob", "logitmfx", "logitor", "logitr", "LORgee", "lrm",
     "margins", "marginaleffects", "marginaleffects.summary", "metaplus", "mixor",
@@ -342,7 +343,7 @@ find_statistic <- function(x, ...) {
     }
 
     if (any(chi_names %in% col_names)) {
-      return("chi-squared statistic")
+      "chi-squared statistic"
     }
   }
 }
