@@ -33,16 +33,14 @@
 #'   (see examples below), while `find_variables()` returns each variable
 #'   name only once.
 #'
-#' @examples
-#' if (require("lme4")) {
-#'   data(sleepstudy)
-#'   m <- suppressWarnings(lmer(
-#'     log(Reaction) ~ Days + I(Days^2) + (1 + Days + exp(Days) | Subject),
-#'     data = sleepstudy
-#'   ))
+#' @examplesIf require("lme4", quietly = TRUE)
+#' data(sleepstudy, package = "lme4")
+#' m <- suppressWarnings(lme4::lmer(
+#'   log(Reaction) ~ Days + I(Days^2) + (1 + Days + exp(Days) | Subject),
+#'   data = sleepstudy
+#' ))
 #'
-#'   find_terms(m)
-#' }
+#' find_terms(m)
 #'
 #' # sometimes, it is necessary to retrieve terms from "term.labels" attribute
 #' m <- lm(mpg ~ hp * (am + cyl), data = mtcars)
@@ -54,7 +52,11 @@ find_terms <- function(x, ...) {
 
 #' @rdname find_terms
 #' @export
-find_terms.default <- function(x, flatten = FALSE, as_term_labels = FALSE, verbose = TRUE, ...) {
+find_terms.default <- function(x,
+                               flatten = FALSE,
+                               as_term_labels = FALSE,
+                               verbose = TRUE,
+                               ...) {
   f <- find_formula(x, verbose = verbose)
 
   if (is.null(f)) {
@@ -136,10 +138,10 @@ find_terms.bfsl <- function(x, flatten = FALSE, verbose = TRUE, ...) {
   resp <- find_response(x, verbose = FALSE)
   f <- find_formula(x, verbose = verbose)
 
-  if (!is.null(f)) {
-    fx <- f[[1]][[3]]
-  } else {
+  if (is.null(f)) {
     fx <- "x"
+  } else {
+    fx <- f[[1]][[3]]
   }
   l <- list(conditional = c(resp, fx))
 
@@ -181,29 +183,39 @@ find_terms.mipo <- function(x, flatten = FALSE, ...) {
   f <- lapply(f, function(.x) {
     if (is.list(.x)) {
       .x <- vapply(.x, .formula_to_string, character(1))
-    } else {
-      if (!is.character(.x)) .x <- safe_deparse(.x)
+    } else if (!is.character(.x)) {
+      .x <- safe_deparse(.x)
     }
     .x
   })
 
+  # save original response
+  original_response <- f$response
+
   # protect "-1"
   f$conditional <- gsub("(-1|- 1)(?![^(]*\\))", "#1", f$conditional, perl = TRUE)
 
+  # This regular expression matches any of the characters *, +, :, |, -, or /,
+  # unless they are preceded by a ^ and followed by a closing parenthesis ).
   f <- lapply(f, function(.x) {
-    pattern <- "[*+:|\\-\\/](?![^(]*\\))" # was: "[\\*\\+:\\-\\|/](?![^(]*\\))"
+    pattern <- "(?<!\\^)[*+:|\\-\\/](?![^(]*\\))" # was: "[\\*\\+:\\-\\|/](?![^(]*\\))"
     f_parts <- gsub("~", "", trim_ws(unlist(
       strsplit(split = pattern, x = .x, perl = TRUE),
       use.names = FALSE
     )), fixed = TRUE)
     # if user has used namespace in formula-functions, these are returned
     # as empty elements. remove those here
-    if (any(nchar(f_parts) == 0)) {
-      f_parts <- f_parts[-which(nchar(f_parts) == 0)]
+    if (!all(nzchar(f_parts, keepNA = TRUE))) {
+      f_parts <- f_parts[-which(!nzchar(f_parts, keepNA = TRUE))]
     }
     text_remove_backticks(unique(f_parts))
   })
 
+  # exceptions where we want to preserve the response value come here
+  # - lm(1 / Sepal.Length ~ Species, data = iris)
+  if (!is.null(original_response) && !is_empty_object(original_response) && startsWith(original_response, "1/")) { # nolint
+    f$response <- original_response
+  }
 
   # remove "1" and "0" from variables in random effects
 
@@ -231,6 +243,7 @@ find_terms.mipo <- function(x, flatten = FALSE, ...) {
   compact_list(f[c(length(f), 1:(length(f) - 1))])
 }
 
+
 .get_variables_list_aovlist <- function(f, resp = NULL) {
   i <- vapply(f[[3]], function(x) {
     x <- as.character(x)
