@@ -11,12 +11,15 @@
 #' "predictions" (a lose term for a variety of things) is a non-trivial process,
 #' with lots of caveats and complications. Read the 'Details' section for more
 #' information.
-#' \cr \cr
-#' `get_predicted_ci()` returns the confidence (or prediction) interval (CI)
+#'
+#' [`get_predicted_ci()`] returns the confidence (or prediction) interval (CI)
 #' associated with predictions made by a model. This function can be called
 #' separately on a vector of predicted values. `get_predicted()` usually
 #' returns confidence intervals (included as attribute, and accessible via the
-#' `as.data.frame()` method) by default.
+#' `as.data.frame()` method) by default. It is preferred to rely on the
+#' `get_predicted()` function for standard errors and confidence intervals -
+#' use `get_predicted_ci()` only if standard errors and confidence intervals
+#' are not available otherwise.
 #'
 #' @param x A statistical model (can also be a data.frame, in which case the
 #'   second argument has to be a model).
@@ -105,9 +108,8 @@
 #' In `insight::get_predicted()`, the `predict` argument jointly
 #' modulates two separate concepts, the **scale** and the **uncertainty interval**.
 #'
-#' \subsection{Confidence Interval (CI) vs. Prediction Interval (PI))}{
-#' \itemize{
-#'   \item **Linear models** - `lm()`: For linear models, Prediction
+#' @section Confidence Interval (CI) vs. Prediction Interval (PI)):
+#' - **Linear models** - `lm()`: For linear models, prediction
 #'   intervals (`predict="prediction"`) show the range that likely
 #'   contains the value of a new observation (in what range it is likely to
 #'   fall), whereas confidence intervals (`predict="expectation"` or
@@ -119,13 +121,12 @@
 #'   Moreover, prediction intervals will not necessarily become narrower as the
 #'   sample size increases (as they do not reflect only the quality of the fit,
 #'   but also the variability within the data).
-#'   \item **Generalized Linear models** - `glm()`: For binomial models,
+#' - **Generalized Linear models** - `glm()`: For binomial models,
 #'   prediction intervals are somewhat useless (for instance, for a binomial
 #'   (Bernoulli) model for which the dependent variable is a vector of 1s and
 #'   0s, the prediction interval is... `[0, 1]`).
-#' }}
 #'
-#' \subsection{Link scale vs. Response scale}{
+#' @section Link scale vs. Response scale:
 #' When users set the `predict` argument to `"expectation"`, the predictions
 #' are returned on the response scale, which is arguably the most convenient
 #' way to understand and visualize relationships of interest. When users set
@@ -138,17 +139,15 @@
 #' function will first calculate predictions as if the user had selected
 #' `predict="expectation"`. Then, it will round the responses in order to
 #' return the most likely outcome.
-#' }
 #'
-#' \subsection{Heteroscedasticity consistent standard errors}{
+#' @section Heteroscedasticity consistent standard errors:
 #' The arguments `vcov` and `vcov_args` can be used to calculate robust
 #' standard errors for confidence intervals of predictions. These arguments,
 #' when provided in `get_predicted()`, are passed down to `get_predicted_ci()`,
 #' thus, see the related documentation there for more
 #' details.
-#' }
 #'
-#' \subsection{Bayesian and Bootstrapped models and iterations}{
+#' @section Bayesian and Bootstrapped models and iterations:
 #' For predictions based on multiple iterations, for instance in the case of Bayesian
 #' models and bootstrapped predictions, the function used to compute the centrality
 #' (point-estimate predictions) can be modified via the `centrality_function`
@@ -156,11 +155,10 @@
 #' The default is `mean`. Individual draws can be accessed by running
 #' `iter <- as.data.frame(get_predicted(model))`, and their iterations can be
 #' reshaped into a long format by `bayestestR::reshape_iterations(iter)`.
-#' }
 #'
 #' @seealso [get_datagrid()]
 #'
-#' @examples
+#' @examplesIf require("boot")
 #' data(mtcars)
 #' x <- lm(mpg ~ cyl + hp, data = mtcars)
 #'
@@ -173,12 +171,10 @@
 #' # Get CI
 #' as.data.frame(predictions)
 #'
-#' if (require("boot")) {
-#'   # Bootstrapped
-#'   as.data.frame(get_predicted(x, iterations = 4))
-#'   # Same as as.data.frame(..., keep_iterations = FALSE)
-#'   summary(get_predicted(x, iterations = 4))
-#' }
+#' # Bootstrapped
+#' as.data.frame(get_predicted(x, iterations = 4))
+#' # Same as as.data.frame(..., keep_iterations = FALSE)
+#' summary(get_predicted(x, iterations = 4))
 #'
 #' # Different prediction types ------------------------
 #' data(iris)
@@ -225,7 +221,7 @@ get_predicted.default <- function(x,
                                   verbose = TRUE,
                                   ...) {
   # evaluate arguments
-  args <- .get_predicted_args(x, data = data, predict = predict, verbose = verbose, ...)
+  my_args <- .get_predicted_args(x, data = data, predict = predict, verbose = verbose, ...)
 
   # evaluate dots, remove some arguments that might be duplicated else
   dot_args <- list(...)
@@ -234,13 +230,13 @@ get_predicted.default <- function(x,
 
 
   # 1. step: predictions
-  predict_args <- compact_list(list(x, newdata = args$data, type = args$type, dot_args))
+  predict_args <- compact_list(list(x, newdata = my_args$data, type = my_args$type, dot_args))
   predictions <- .safe(do.call("predict", predict_args))
 
   # may fail due to invalid "dot_args", so try shorter argument list
   if (is.null(predictions)) {
     predictions <- .safe(
-      do.call("predict", compact_list(list(x, newdata = args$data, type = args$type)))
+      do.call("predict", compact_list(list(x, newdata = my_args$data, type = my_args$type)))
     )
   }
 
@@ -261,8 +257,8 @@ get_predicted.default <- function(x,
     get_predicted_ci(
       x,
       predictions,
-      data = args$data,
-      ci_type = args$ci_type,
+      data = my_args$data,
+      ci_type = my_args$ci_type,
       ci_method = ci_method,
       vcov = vcov,
       vcov_args = vcov_args,
@@ -271,15 +267,15 @@ get_predicted.default <- function(x,
   })
 
   # 3. step: back-transform
-  if (!is.null(predictions)) {
-    out <- .get_predicted_transform(x, predictions, args, ci_data, verbose = verbose)
-  } else {
+  if (is.null(predictions)) {
     out <- NULL
+  } else {
+    out <- .get_predicted_transform(x, predictions, my_args = my_args, ci_data, verbose = verbose)
   }
 
   # 4. step: final preparation
   if (!is.null(out)) {
-    out <- .get_predicted_out(out$predictions, args = args, ci_data = out$ci_data)
+    out <- .get_predicted_out(out$predictions, my_args = my_args, ci_data = out$ci_data)
   }
 
   out
@@ -313,11 +309,11 @@ get_predicted.lm <- function(x,
   predict_function <- function(x, data, ...) {
     stats::predict(x,
       newdata = data, interval = "none",
-      type = args$type, se.fit = FALSE, ...
+      type = my_args$type, se.fit = FALSE, ...
     )
   }
 
-  args <- .get_predicted_args(x, data = data, predict = predict, verbose = verbose, ...)
+  my_args <- .get_predicted_args(x, data = data, predict = predict, verbose = verbose, ...)
 
   # 0. step: convert matrix variable types attributes to numeric, if necessary.
   # see https://github.com/easystats/insight/pull/671
@@ -326,7 +322,7 @@ get_predicted.lm <- function(x,
     dataClasses[dataClasses == "nmatrix.1"] <- "numeric"
     attributes(x$terms)$dataClasses <- dataClasses
     attributes(attributes(x$model)$terms)$dataClasses <- dataClasses
-    args$data[] <- lapply(args$data, function(x) {
+    my_args$data[] <- lapply(my_args$data, function(x) {
       if (all(class(x) == c("matrix", "array"))) { # nolint
         as.numeric(x)
       } else {
@@ -337,11 +333,11 @@ get_predicted.lm <- function(x,
 
   # 1. step: predictions
   if (is.null(iterations)) {
-    predictions <- predict_function(x, data = args$data)
+    predictions <- predict_function(x, data = my_args$data)
   } else {
     predictions <- .get_predicted_boot(
       x,
-      data = args$data,
+      data = my_args$data,
       predict_function = predict_function,
       iterations = iterations,
       verbose = verbose,
@@ -353,18 +349,18 @@ get_predicted.lm <- function(x,
   ci_data <- get_predicted_ci(
     x,
     predictions,
-    data = args$data,
+    data = my_args$data,
     ci = ci,
-    ci_type = args$ci_type,
+    ci_type = my_args$ci_type,
     verbose = verbose,
     ...
   )
 
   # 3. step: back-transform
-  out <- .get_predicted_transform(x, predictions, args, ci_data, verbose = verbose)
+  out <- .get_predicted_transform(x, predictions, my_args, ci_data, verbose = verbose)
 
   # 4. step: final preparation
-  .get_predicted_out(out$predictions, args = args, ci_data = out$ci_data)
+  .get_predicted_out(out$predictions, my_args = my_args, ci_data = out$ci_data)
 }
 
 #' @export
@@ -415,16 +411,16 @@ get_predicted.coxph <- function(x,
                                 iterations = NULL,
                                 verbose = TRUE,
                                 ...) {
-  args <- .get_predicted_args(x, data = data, predict = predict, verbose = verbose, ...)
+  my_args <- .get_predicted_args(x, data = data, predict = predict, verbose = verbose, ...)
   se <- NULL
 
   predict_function <- function(x, data, ...) {
-    stats::predict(x, newdata = data, type = args$type, ...)
+    stats::predict(x, newdata = data, type = my_args$type, ...)
   }
 
   # 1. step: predictions
   if (is.null(iterations)) {
-    predictions <- predict_function(x, data = args$data, se.fit = TRUE)
+    predictions <- predict_function(x, data = my_args$data, se.fit = TRUE)
     if (is.list(predictions)) {
       se <- as.vector(predictions$se.fit)
       predictions <- as.vector(predictions$fit)
@@ -432,7 +428,7 @@ get_predicted.coxph <- function(x,
   } else {
     predictions <- .get_predicted_boot(
       x,
-      data = args$data,
+      data = my_args$data,
       predict_function = predict_function,
       iterations = iterations,
       verbose = verbose,
@@ -444,18 +440,18 @@ get_predicted.coxph <- function(x,
   ci_data <- get_predicted_ci(
     x,
     predictions,
-    data = args$data,
+    data = my_args$data,
     ci = ci,
-    ci_type = args$ci_type,
+    ci_type = my_args$ci_type,
     se = se,
     ...
   )
 
   # 3. step: back-transform
-  out <- .get_predicted_transform(x, predictions, args, ci_data, link_inv = exp, verbose = verbose)
+  out <- .get_predicted_transform(x, predictions, my_args, ci_data, link_inv = exp, verbose = verbose)
 
   # 4. step: final preparation
-  .get_predicted_out(out$predictions, args = args, ci_data = out$ci_data)
+  .get_predicted_out(out$predictions, my_args = my_args, ci_data = out$ci_data)
 }
 
 
@@ -470,17 +466,17 @@ get_predicted.bife <- function(x,
                                data = NULL,
                                verbose = TRUE,
                                ...) {
-  args <- .get_predicted_args(x,
+  my_args <- .get_predicted_args(x,
     data = data,
     predict = predict,
     verbose = TRUE,
     ...
   )
 
-  out <- .safe(stats::predict(x, type = args$scale, X_new = args$data))
+  out <- .safe(stats::predict(x, type = my_args$scale, X_new = my_args$data))
 
   if (!is.null(out)) {
-    out <- .get_predicted_out(out, args = list("data" = data))
+    out <- .get_predicted_out(out, my_args = list(data = data))
   }
 
   out
@@ -498,7 +494,7 @@ get_predicted.rma <- function(x,
                               transf = NULL,
                               transf_args = NULL,
                               ...) {
-  args <- .get_predicted_args(x,
+  my_args <- .get_predicted_args(x,
     data = data,
     predict = predict,
     verbose = TRUE,
@@ -571,7 +567,7 @@ get_predicted.rma <- function(x,
     if (nrow(out) == 1) {
       out <- do.call(rbind, lapply(seq_along(x$slab), function(i) out))
     }
-    out <- .get_predicted_out(out, args = list("data" = data))
+    out <- .get_predicted_out(out, my_args = list(data = data))
   }
 
   out
@@ -586,19 +582,19 @@ get_predicted.rma <- function(x,
 #' @export
 get_predicted.afex_aov <- function(x, data = NULL, ...) {
   if (is.null(data)) {
-    args <- c(list(x), list(...))
+    my_args <- c(list(x), list(...))
   } else {
-    args <- c(list(x, "newdata" = data), list(...))
+    my_args <- c(list(x, newdata = data), list(...))
   }
 
-  out <- .safe(do.call("predict", args))
+  out <- .safe(do.call("predict", my_args))
 
   if (is.null(out)) {
-    out <- .safe(do.call("fitted", args))
+    out <- .safe(do.call("fitted", my_args))
   }
 
   if (!is.null(out)) {
-    out <- .get_predicted_out(out, args = list("data" = data))
+    out <- .get_predicted_out(out, my_args = list(data = data))
   }
 
   out
@@ -617,7 +613,7 @@ get_predicted.phylolm <- function(x,
                                   verbose = TRUE,
                                   ...) {
   # evaluate arguments
-  args <- .get_predicted_args(x, data = data, predict = predict, verbose = verbose, ...)
+  my_args <- .get_predicted_args(x, data = data, predict = predict, verbose = verbose, ...)
 
   # evaluate dots, remove some arguments that might be duplicated else
   dot_args <- list(...)
@@ -626,13 +622,13 @@ get_predicted.phylolm <- function(x,
 
 
   # 1. step: predictions
-  predict_args <- compact_list(list(x, newdata = args$data, type = args$type, dot_args))
+  predict_args <- compact_list(list(x, newdata = my_args$data, type = my_args$type, dot_args))
   predictions <- .safe(do.call("predict", predict_args))
 
   # may fail due to invalid "dot_args", so try shorter argument list
   if (is.null(predictions)) {
     predictions <- .safe(
-      do.call("predict", compact_list(list(x, newdata = args$data, type = args$type)))
+      do.call("predict", compact_list(list(x, newdata = my_args$data, type = my_args$type)))
     )
   }
 
@@ -649,7 +645,7 @@ get_predicted.phylolm <- function(x,
   }
   # 2. step: final preparation
   if (!is.null(out)) {
-    out <- .get_predicted_out(predictions, args = args, ci_data = NULL)
+    out <- .get_predicted_out(predictions, my_args = my_args, ci_data = NULL)
   }
 
   out
@@ -698,13 +694,13 @@ get_predicted.phylolm <- function(x,
 
 .get_predicted_transform <- function(x,
                                      predictions,
-                                     args = NULL,
+                                     my_args = NULL,
                                      ci_data = NULL,
                                      link_inv = NULL,
                                      verbose = FALSE,
                                      ...) {
   # Transform to response scale
-  if (isTRUE(args$transform)) {
+  if (isTRUE(my_args$transform)) {
     # retrieve link-inverse, for back transformation...
     if (is.null(link_inv)) {
       link_inv <- link_inverse(x)
@@ -741,17 +737,17 @@ get_predicted.phylolm <- function(x,
 
     # Transform iterations
     if ("iterations" %in% names(attributes(predictions))) {
-      attr(predictions, "iterations") <- as.data.frame(sapply(attributes(predictions)$iterations, link_inv))
+      attr(predictions, "iterations") <- as.data.frame(sapply(attributes(predictions)$iterations, link_inv)) # nolint
     }
 
     # Transform to response "type"
-    if (args$predict == "classification" && model_info(x, verbose = FALSE)$is_binomial) {
+    if (my_args$predict == "classification" && model_info(x, verbose = FALSE)$is_binomial) {
       response <- get_response(x, as_proportion = TRUE)
       ci_data[!se_col] <- lapply(ci_data[!se_col], .get_predict_transform_response, response = response)
       predictions <- .get_predict_transform_response(predictions, response = response)
       if ("iterations" %in% names(attributes(predictions))) {
         attr(predictions, "iterations") <- as.data.frame(
-          sapply(
+          sapply( # nolint
             attributes(predictions)$iterations,
             .get_predict_transform_response,
             response = response
@@ -769,27 +765,27 @@ get_predicted.phylolm <- function(x,
 
 # -------------------------------------------------------------------------
 
-.get_predicted_out <- function(predictions, args = NULL, ci_data = NULL, ...) {
+.get_predicted_out <- function(predictions, my_args = NULL, ci_data = NULL, ...) {
   if (!is.null(ci_data)) {
     attr(predictions, "ci_data") <- ci_data
   }
-  if (!is.null(args)) {
-    attr(predictions, "data") <- args$data
-    attr(predictions, "ci") <- args$ci
-    attr(predictions, "predict") <- args$predict
+  if (!is.null(my_args)) {
+    attr(predictions, "data") <- my_args$data
+    attr(predictions, "ci") <- my_args$ci
+    attr(predictions, "predict") <- my_args$predict
   }
 
   # multidimensional or "grouped" predictions (e.g., nnet::multinom with `predict(type="probs")`)
-  if (is.matrix(predictions) && ncol(predictions) > 1) {
+  if (is.matrix(predictions) && ncol(predictions) > 1L) {
     predictions <- as.data.frame(predictions)
     vary <- colnames(predictions)
     predictions$Row <- seq_len(nrow(predictions))
     # if we have any focal predictors, add those as well, so we have
     # the associated levels/values for "Row"
-    if (!is.null(args$data)) {
-      focal_predictors <- .safe(names(which(n_unique(args$data) > 1)))
+    if (!is.null(my_args$data)) {
+      focal_predictors <- .safe(names(which(n_unique(my_args$data) > 1L)))
       if (!is.null(focal_predictors)) {
-        predictions <- cbind(predictions, args$data[focal_predictors])
+        predictions <- cbind(predictions, my_args$data[focal_predictors])
       }
     }
     predictions <- stats::reshape(predictions,
