@@ -1,6 +1,10 @@
 # small wrapper around this commonly used try-catch
 .safe <- function(code, on_error = NULL) {
-  tryCatch(code, error = function(e) on_error)
+  if (isTRUE(getOption("easystats_errors", FALSE)) && is.null(on_error)) {
+    code
+  } else {
+    tryCatch(code, error = function(e) on_error)
+  }
 }
 
 
@@ -118,14 +122,14 @@
 }
 
 
-
 # extract random effects from formula
 .get_model_random <- function(f, model, split_nested = FALSE) {
   is_special <- inherits(
     model,
     c(
       "MCMCglmm", "gee", "LORgee", "mixor", "clmm2", "felm", "feis", "bife",
-      "BFBayesFactor", "BBmm", "glimML", "MANOVA", "RM", "cglm", "glmm"
+      "BFBayesFactor", "BBmm", "glimML", "MANOVA", "RM", "cglm", "glmm",
+      "glmgee"
     )
   )
 
@@ -190,7 +194,6 @@
 }
 
 
-
 # in case we need the random effects terms as formula (symbol),
 # not as character string, then call this functions instead of
 # .get_model_random()
@@ -215,10 +218,8 @@
 }
 
 
-
 # helper to access model components ----------------
 
-
 .all_elements <- function() {
   c(
     "conditional", "conditional1", "conditional2", "conditional3", "precision",
@@ -243,7 +244,7 @@
   )
 }
 
-.get_elements <- function(effects, component) {
+.get_elements <- function(effects, component, model = NULL) {
   # all elements of a model
   elements <- .all_elements()
 
@@ -279,6 +280,13 @@
     return(auxiliary_parameters)
   }
 
+  # if we have brms-models with custom formulas, we have element-names
+  # that are not covered by the standard elements. We then just do not
+  # filter elements.
+  if (inherits(model, "brmsfit") && component == "all") {
+    f <- insight::find_formula(model)
+    elements <- unique(c(elements, names(f)))
+  }
 
   elements <- switch(effects,
     all = elements,
@@ -299,48 +307,6 @@
 }
 
 
-
-
-# checks if a mixed model fit is singular or not. Need own function,
-# because lme4::isSingular() does not work with glmmTMB
-.is_singular <- function(x, vals, tolerance = 1e-5) {
-  check_if_installed("lme4", reason = "to compute variances for mixed models")
-
-  tryCatch(
-    {
-      if (inherits(x, "glmmTMB")) {
-        eigen_values <- list()
-        for (component in c("cond", "zi")) {
-          for (i in seq_along(vals$vc[[component]])) {
-            eigen_values <- c(eigen_values, list(eigen(vals$vc[[component]][[i]], only.values = TRUE)$values))
-          }
-        }
-        is_si <- any(vapply(eigen_values, min, numeric(1), na.rm = TRUE) < tolerance)
-      } else if (inherits(x, c("clmm", "cpglmm"))) {
-        is_si <- any(sapply(vals$vc, function(.x) any(abs(diag(.x)) < tolerance)))
-      } else if (inherits(x, "merMod")) {
-        theta <- lme4::getME(x, "theta")
-        diag.element <- lme4::getME(x, "lower") == 0
-        is_si <- any(abs(theta[diag.element]) < tolerance)
-      } else if (inherits(x, "MixMod")) {
-        vc <- diag(x$D)
-        is_si <- any(sapply(vc, function(.x) any(abs(.x) < tolerance)))
-      } else if (inherits(x, "lme")) {
-        is_si <- any(abs(stats::na.omit(as.numeric(diag(vals$vc))) < tolerance))
-      } else {
-        is_si <- FALSE
-      }
-
-      is_si
-    },
-    error = function(x) {
-      FALSE
-    }
-  )
-}
-
-
-
 # Filter parameters from Stan-model fits
 .filter_pars <- function(l, parameters = NULL, is_mv = NULL) {
   if (!is.null(parameters)) {
@@ -361,7 +327,6 @@
 }
 
 
-
 .filter_pars_univariate <- function(l, parameters) {
   lapply(l, function(component) {
     unlist(sapply(
@@ -375,14 +340,12 @@
 }
 
 
-
 # remove column
 .remove_column <- function(data, variables) {
   data[, -which(colnames(data) %in% variables), drop = FALSE]
 }
 
 
-
 .grep_smoothers <- function(x) {
   startsWith(x, "s(") |
     startsWith(x, "ti(") |
@@ -400,7 +363,6 @@
 }
 
 
-
 .grep_zi_smoothers <- function(x) {
   grepl("^(s\\.\\d\\()", x, perl = TRUE) |
     grepl("^(gam::s\\.\\d\\()", x, perl = TRUE) |
@@ -408,7 +370,6 @@
 }
 
 
-
 .grep_non_smoothers <- function(x) {
   grepl("^(?!(s\\())", x, perl = TRUE) &
     # this one captures smoothers in zi- or mv-models from gam
@@ -429,7 +390,6 @@
 }
 
 
-
 # .split_formula <- function(f) {
 #   rhs <- if (length(f) > 2L)
 #     f[[3L]]
@@ -454,7 +414,6 @@
 # }
 
 
-
 .gam_family <- function(x) {
   faminfo <- .safe(stats::family(x))
 
@@ -467,7 +426,6 @@
 }
 
 
-
 # for models with zero-inflation component, return
 # required component of model-summary
 .filter_component <- function(dat, component) {
@@ -488,8 +446,6 @@
 }
 
 
-
-
 #' @keywords internal
 .gather <- function(x,
                     names_to = "key",
@@ -516,7 +472,6 @@
 }
 
 
-
 .is_baysian_emmeans <- function(x) {
   if (inherits(x, "emm_list")) {
     x <- x[[1]]
@@ -526,19 +481,21 @@
 }
 
 
-
-.is_bayesian_model <- function(x) {
-  inherits(x, c(
-    "brmsfit", "stanfit", "MCMCglmm", "stanreg",
-    "stanmvreg", "bmerMod", "BFBayesFactor", "bamlss",
-    "bayesx", "mcmc", "bcplm", "bayesQR", "BGGM",
-    "meta_random", "meta_fixed", "meta_bma", "blavaan",
-    "blrm"
-  ))
+.is_bayesian_model <- function(x, exclude = NULL) {
+  bayes_classes <- c(
+    "brmsfit", "stanfit", "MCMCglmm", "stanreg", "stanmvreg", "bmerMod",
+    "BFBayesFactor", "bamlss", "bayesx", "mcmc", "bcplm", "bayesQR", "BGGM",
+    "meta_random", "meta_fixed", "meta_bma", "blavaan", "blrm", "blmerMod",
+    "bglmerMod"
+  )
+  # if exclude is not NULL, remove elements in exclude from bayes_class
+  if (!is.null(exclude)) {
+    bayes_classes <- bayes_classes[!bayes_classes %in% exclude]
+  }
+  inherits(x, bayes_classes)
 }
 
 
-
 # safe conversion from factor to numeric
 .factor_to_numeric <- function(x, lowest = NULL) {
   if (is.data.frame(x)) {
@@ -585,9 +542,6 @@
 }
 
 
-
-
-
 ## copied from lme4::findbars() -----------------------
 
 
@@ -603,7 +557,6 @@
 }
 
 
-
 .expandDoubleVerts <- function(term) {
   if (!is.name(term) && is.language(term)) {
     if (term[[1]] == as.name("(")) {
@@ -622,7 +575,6 @@
 }
 
 
-
 .findbars <- function(term) {
   fb <- function(term) {
     if (is.name(term) || !is.language(term)) {
@@ -687,8 +639,6 @@
 }
 
 
-
-
 ## copied from lme4::nobars() -----------------------
 
 
@@ -708,7 +658,6 @@
 }
 
 
-
 .nobars_ <- function(term) {
   if (!(any(c("|", "||") %in% all.names(term)))) {
     return(term)
@@ -748,7 +697,6 @@
 }
 
 
-
 .isBar <- function(term) {
   if (is.call(term) && ((term[[1]] == as.name("|") || term[[1]] == as.name("||")))) {
     return(TRUE)
@@ -769,7 +717,6 @@
 }
 
 
-
 # classify emmeans objects -------------
 
 
