@@ -515,6 +515,7 @@ model_info.MixMod <- function(x, verbose = TRUE, ...) {
   .make_family(
     x = x,
     fitfam = faminfo$family,
+    zero.inf = !is.null(stats::formula(x, type = "zi_fixed")),
     logit.link = faminfo$link == "logit",
     link.fun = faminfo$link,
     verbose = verbose,
@@ -1001,6 +1002,19 @@ model_info.glmmadmb <- function(x, ...) {
 }
 
 
+#' @export
+model_info.glmgee <- function(x, ...) {
+  faminfo <- x$family
+  .make_family(
+    x = x,
+    fitfam = faminfo$family,
+    logit.link = faminfo$link == "logit",
+    link.fun = faminfo$link,
+    ...
+  )
+}
+
+
 #' @export
 model_info.cpglmm <- function(x, ...) {
   link <- parse(text = safe_deparse(x@call))[[1]]$link
@@ -1110,9 +1124,14 @@ model_info.svy_vglm <- function(x, verbose = TRUE, ...) {
 }
 
 
+#' @export
+model_info.svy2lme <- function(x, verbose = TRUE, ...) {
+  .make_family(x = x, verbose = verbose, ...)
+}
+
+
 #' @export
 model_info.glmmTMB <- function(x, ...) {
-  # installed?
   check_if_installed("lme4")
 
   faminfo <- stats::family(x)
